/**
 * Remembers method result and caches it
 * <br>Should <b>only</b> be used on <b>pure</b> functions!
 * @since 4.0.0
 */
export function RememberResult(hashFn) {
    return function (target, propertyKey, descriptor) {
        const cache = new Map();
        const ogMethod = descriptor.value;
        descriptor.value = function (...args) {
            const key = hashFn ? hashFn.apply(this, args) : JSON.stringify(args);
            const cacheEntry = cache.get(key);
            if (cacheEntry) {
                return cacheEntry;
            }
            cache.set(key, ogMethod.apply(this, args));
            return cache.get(key);
        };
        return descriptor;
    };
}
//# sourceMappingURL=remember-result.js.map