import { UndefinedOr } from '../../types';
/**
 * Stopwatch - Stops the time
 * <br> Use <code>start()</code> to start it and <code>stop()</code> to stop it. You can also reset it via
 * <code>reset()</code>.
 * <br> Check the Stopwatch status with: <code>hasStarted()</code>, <code>isRunning()</code> and <code>isStopped()</code>.
 * <br> Laps can be created with <code>lap(string)</code> and read with <code>getLaps()</code>, you can also
 * subscribe to <code>lapsChange</code>.
 * <br> The time can be read via <code>getTime()</code>, <code>getTimeInSeconds()</code>, <code>getTimeInMinutes()</code>
 * and <code>getTimeInHours()</code>.
 * @since 3.2.5
 */
export declare class Stopwatch {
    private startedAt;
    private endedAt;
    private laps;
    constructor(start?: boolean);
    hasStarted(): boolean;
    isRunning(): boolean;
    isStopped(): boolean;
    /**
     * Starts stopwatch (only once)
     * @return {Date} Date at which the stopwatch was started
     */
    start(): Date;
    /**
     * Stops stopwatch (only once)
     * @return {Date} Date at which the stopwatch was stopped
     */
    stop(): Date;
    /**
     * Stops stopwatch and returns elapsed time in milliseconds
     * @return {number} Elapsed time in milliseconds
     */
    stopAndGetTime(): number;
    /**
     * Stops stopwatch and returns elapsed time in seconds
     * @return {number} Elapsed time in seconds
     */
    stopAndGetTimeInSeconds(): number;
    /**
     * Stops stopwatch and returns elapsed time in minutes
     * @return {number} Elapsed time in minutes
     */
    stopAndGetTimeInMinutes(): number;
    /**
     * Stops stopwatch and returns elapsed time in hours
     * @return {number} Elapsed time in hours
     */
    stopAndGetTimeInHours(): number;
    /**
     * Resets complete stopwatch
     */
    reset(): void;
    /**
     * @return {number} Elapsed time in milliseconds
     */
    getTime(): number;
    /**
     * @return {number} Elapsed time in seconds
     */
    getTimeInSeconds(): number;
    /**
     * @return {number} Elapsed time in minutes
     */
    getTimeInMinutes(): number;
    /**
     * @return {number} Elapsed time in hours
     */
    getTimeInHours(): number;
    /**
     * Creates a lap with optional string, notifies all lap subscribers
     * @param {string} text
     * @return {Date} Date when the lap was set
     */
    lap(text?: string): Date;
    /**
     * Returns all laps
     * @return {Map<number, UndefinedOr<string>>} All laps
     */
    getLaps(): Map<number, UndefinedOr<string>>;
    static createStarted(): Stopwatch;
    static createStopped(): Stopwatch;
}
//# sourceMappingURL=stopwatch.d.ts.map