export function s_imploder() {
    return new ImploderBuilder();
}
export class ImploderBuilder {
    source(source, mapFn) {
        if (source) {
            if (source.every((it) => typeof it === 'string')) {
                this._source = source;
            }
            else if (mapFn) {
                this._source = source.map(mapFn);
            }
            else {
                throw 'mapFn required on none string arrays';
            }
        }
        return this;
    }
    maxLength(maxLength) {
        this._maxLength = maxLength;
        return this;
    }
    offset(offset) {
        this._offset = offset;
        return this;
    }
    separator(separator) {
        this._separator = separator;
        return this;
    }
    suffix(suffix) {
        this._suffix = suffix;
        return this;
    }
    forceSuffix(forceSuffix) {
        this._forceSuffix = forceSuffix;
        return this;
    }
    build() {
        if (!this._source) {
            return '';
        }
        let source = this._source;
        if (this._offset) {
            source = source.slice(this._offset, source.length);
        }
        const joinedSource = source.join(this._separator ?? '');
        if (this._maxLength && joinedSource.length > this._maxLength) {
            return `${joinedSource.slice(0, this._maxLength)}${this._suffix ?? ''}`;
        }
        return `${joinedSource}${this._forceSuffix ? this._suffix ?? '' : ''}`;
    }
}
//# sourceMappingURL=imploder.js.map